@@ -1,7 +1,6 @@
 from .Extractors import PostExtractor, CommentExtractor, GroupExtractor, MembersExtractor
 from .Extractors import PersonExtractor, InteractionExtractor, EventExtractor
 
-# import pickle
 import sys
 import os
 import logging
@@ -99,6 +98,8 @@ class Extractor(object):
         nodes_pd = extractor.nodes.to_pandas(self)
         nodes_pd.replace(to_replace=[r"\\t|\\n|\\r", "\t|\n|\r"], value=[" ", " "], regex=True)
 
+        print('done')
+
         return nodes_pd
 
     async def fetch(self, http_calls):
